@@ -5,6 +5,10 @@ pref("imagezoom.mmFitWindow", false);
 pref("imagezoom.mmReset", false);
 pref("imagezoom.mmZoomIO", false);
 pref("imagezoom.mmZoomPcts", false);
+pref("imagezoom.mmRotateRight", false);
+pref("imagezoom.mmRotateLeft", false);
+pref("imagezoom.mmRotate180", false);
+pref("imagezoom.mmRotateReset", false);
 pref("imagezoom.usescroll", true);
 pref("imagezoom.triggerbutton", 3);
 pref("imagezoom.imagefitbutton", 1);
@@ -16,15 +20,14 @@ pref("imagezoom.smFitWindow", true);
 pref("imagezoom.smReset", true);
 pref("imagezoom.smZoomIO", true);
 pref("imagezoom.smZoomPcts", true);
+pref("imagezoom.smRotateRight", true);
+pref("imagezoom.smRotateLeft", true);
+pref("imagezoom.smRotate180", true);
+pref("imagezoom.smRotateReset", true);
 pref("imagezoom.zoomvalue", 200);
 pref("imagezoom.version", "0.0.0");
 pref("imagezoom.reversescrollzoom", false);
 pref("imagezoom.scrollmode", 0);
-pref("imagezoom.showViewMenu", false);
-pref("imagezoom.defaultGlobalZoom", "100");
 pref("imagezoom.scrollZoomMode", 0);
-pref("imagezoom.autofitlargeimage", false);
-pref("imagezoom.showAutoFitInMenu", true);
 pref("imagezoom.toggleFitReset", false);
-pref("imagezoom.globalZoomWarning", true);
-pref("extensions.{1A2D0EC4-75F5-4c91-89C4-3656F6E44B68}.description", "chrome://imagezoom/locale/imageZoom.properties");
+pref("extensions.{1A2D0EC4-75F5-4c91-89C4-3656F6E44B68}.description", "chrome://net.yellowgorilla.imagezoom/locale/imageZoom.properties");
